/*
 * libexplain - a library of system-call-specific strerror replacements
 * Copyright (C) 2011, 2013 Peter Miller
 * Written by Peter Miller <pmiller@opensource.org.au>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBEXPLAIN_PROCESS_EXISTS_H
#define LIBEXPLAIN_PROCESS_EXISTS_H

#include <libexplain/ac/unistd.h>

/**
  * The explain_process_exists function may be used to determine whether
  * or not the given process actually exists.
  *
  * @param pid
  *    The process ID to search for.
  * @returns
  *     boolean; true (non zero) if the process exists, false 9zero) if the
  *     process does not exists.
  * @note
  *     This has inevitable race conditions, because we aren't in the
  *     kernel, and can't take the appropriate lock.
  */
int explain_process_exists(pid_t pid);

#endif /* LIBEXPLAIN_PROCESS_EXISTS_H */
/* vim: set ts=8 sw=4 et : */
